
# NAME

osmium-renumber - renumber object IDs


# SYNOPSIS

**osmium renumber** \[*OPTIONS*\] *OSM-DATA-FILE*


# DESCRIPTION

The objects (nodes, ways, and relations) in an OSM file often have very large
IDs. This can make some kinds of postprocessing difficult. This command will
renumber all objects using IDs starting at 1. Referential integrity will be
kept. All objects which appear in the source file will be in the same order
in the output file. IDs of objects which are not in the file but referenced
from ways or relations are not guaranteed to be in the correct order.

This command expects the input file to be ordered in the usual way: First
nodes in order of ID, then ways in order of ID, then relations in order of ID.
The input file will be read twice, so it will not work with STDIN.

Currently this command can not renumber negative IDs.

You must never upload the data generated by this command to OSM! This would
really confuse the OSM database because it knows the objects under different
IDs.


# OPTIONS

-i, --index-directory=DIR
:   Directory where the index files for mapping between old and news IDs are
    read from and written to, respectively. Use this if you want to map IDs
    in several OSM files. Without this option, the indexes are not read from
    or written to disk. The directory must exist. Use '.' for the current
    directory. The files written will be named `nodes.idx`, `ways.idx`, and
    `relations.idx`. See also the **INDEX FILES** section below.

-t, --object-type=TYPE
:   Renumber only objects of given type (*node*, *way*, or *relation*). By
    default all objects of all types are renumbered. This option can be given
    multiple times.

@MAN_COMMON_OPTIONS@
@MAN_PROGRESS_OPTIONS@
@MAN_INPUT_OPTIONS@
@MAN_OUTPUT_OPTIONS@


# INDEX FILES

When the `-i` or `--index-directory` option is used, index files named
`nodes.idx`, `ways.idx`, and `relations.idx` are read from and written to the
given directory. This can be used to force consistent mapping over several
invocations of `osmium renumber`, for instance when you want to remap an OSM
data file and a corresponding OSM change file.

The index files are in binary format, but you can use the following command
line to convert them into something readable:

    od -An -td8 -w8 TYPE.idx | cat -n


# DIAGNOSTICS

**osmium renumber** exits with exit code

0
  ~ if everything went alright,

1
  ~ if there was an error processing the data, or

2
  ~ if there was a problem with the command line arguments.


# MEMORY USAGE

**osmium renumber** needs quite a bit of main memory to keep the mapping
between old and new IDs. It is intended for small to medium sized extracts.
You will need more than 32 GB RAM to run this on a full planet.

Memory use is at least 8 bytes per node, way, and relation ID in the input
file.


# EXAMPLES

Renumber a PBF file and output to a compressed XML file:

    osmium renumber -o ch.osm.bz2 germany.osm.pbf

Renumbering Germany currently (spring 2016) takes less than three minutes and
needs about 3 GB RAM.

Renumber an OSM file storing the indexes on disk:

    osmium renumber -i. -o renumbered.osm data.osm

then rewrite a change file, too:

    osmium renumber -i. -o renumbered.osc changes.osc


# SEE ALSO

* **osmium**(1), **osmium-file-formats**(5)
* [Osmium website](http://osmcode.org/osmium-tool/)

